# Colosseum

To run the Colosseum server for testing, refer to [the server repo](https://github.com/PettingZoo-Team/Colosseum-Server).

To run a client you can use the following command:

```
python -m test_agent user1 password --host localhost --port 12345 --game boxing_v1
```

Or you can run `python -m test_agent --help` to learn more about using the test agent.
